Learn R Programming

scrime (version 1.2.9)

colEpistatic: Cordell's Test for Epistatic Interactions

Description

Performs the likelihood ratio test for epistatic interactions proposed by Cordell (2002) for case-control data, where colEpistatic assumes that each column represents a SNP, and rowEpistatic assumes that each row represents a SNP.

Usage

colEpistatic(mat.snp, cl, genes = NULL, warnError = TRUE)
rowEpistatic(mat.snp, cl, genes = NULL, warnError = TRUE)

## S3 method for class 'colEpi':
print(x, top = 5, digits = 4, ...)

Arguments

mat.snp
a matrix containing genotype data, where the genotypes of each SNPs need to be coded by the number of minor alleles, i.e. 0, 1, and 2. Missing values are allowed. For colEpistatic, each column of mat.snp is assumed to repres
cl
a numeric vector of ones and zeros specifying which of the subjects in mat.snp are cases (coded by 1) and which are controls (coded by 0).
genes
a character vector containing the names of the genes (or, e.g., LD-blocks or pathways) to which the SNPs belong. If specified, only the two-way interactions between SNPs from different genetic sets (e.g., genes, LD-blocks, or pathways) are tested.
warnError
logical indicating whether the statistics for the gTDT for pairs of SNPs should be returned as NA if the fitting of one of the logistic regression models with glm returns warning. If
x
an object of class colEpi, i.e. the output of either colEpistatic or rowEpistatic.
top
number of interactions that should be printed. If top is set to 0 or the number of interactions is smaller than or equal to top, then the statistics for all interactions are printed in the order of their comput
digits
number of digits that should be printed.
...
ignored.

Value

  • An object of class colEpi consisting of
  • ll.maina numeric vector containing the values of the maximized loglikelihoods of the logistic regression models considering only main effects,
  • ll.fulla numeric vector containing the values the maximized loglikelihoods of the logistic regression models additionally containing interaction terms,
  • stata vector comprising the values of the test statistic,
  • pvala vector comprising the corresponding p-values,
  • genesif genes has been specified, a vector composed of the gene pairs to which the SNP pairs belong,
  • vec.errorif warnError = TRUE, a list in which an entry corresponding to a SNP pair for which the fitting of (at least) one of the logistic regression models led to a warning shows this warning message of glm, and all other entries are NULL.

References

Cordell, H. J. (2002). Epistasis: What it Means, what it Doesn't mean, and Statistical Methods to Detect it in Humans. Human Molecular Genetics, 11, 2463-2468.

See Also

colTDT2way