levels
a vector of length three specifying the values with which the three
genotypes of each SNP are represented. It is assumed that the second element of
levels represents the heterozygous genotype, whereas the first and the
third eleme
affy
logical specifying whether the SNPs in x are coded as in the Affymetrix
standard output. If TRUE, levels = c("AA", "AB", "BB") will be used.
check
should some checks be done if, e.g., other than the specified levels
are used in x? It is highly recommended to leave check = TRUE. Setting
check = FALSE will reduce the computation time slightly