x
a matrix in which each row represents a SNP and each column a subject,
where the genotypes of each SNP are coded by 1 (for the homozygous reference genotype),
2 (heterozygous), and 3 (homozygous variant). NAs are also allowed.
check
should it be checked if the matrix contains values differing from 1, 2, and 3?
It is highly recommended to leave check = TRUE. Setting check = FALSE
reduces the computation time only slightly.