theta / sqrt(V)
that under the null hypothesis are assumed to follow an asymptotic standard normal distribution.abf(theta, V, W, numerator = 0, pi1 = NA)theta containing the variances of the estimates comprised by theta.theta consisting of
positive values.theta specifying for each of the SNPs a prior probability that this SNP is associated with the response.
If spi1 = NA, a vector of the same length as theta containing the values of the approximate Bayes factor.
If pi1 is specified, a list consisting ofnumerator = 1)
or no association (if numerator = 0),numerator = 1) or no association
(if numerator = 0),numerator = 0),numerator = 1)l