Usage
rowTrendFuzzy(score, probs, y, mat.fuzzy = NULL, alternative = c("two.sided", "less", "greater"),
check = TRUE)
getMatFuzzy(score, probs, check = TRUE)Arguments
score
either a numeric vector of length 2 or 3, or a character string.
If the latter, score must
be either "additive", "dominant", "recessive", or an abbreviation of these terms. If
probs
a list of length 2 or 3 consisting of matrices of the same size. Each matrix must contain the confidences
for one of the three genotypes, where each row in the matrix represents a SNP and each column a sample (which must be in the same
order in
y
a vector of zeros and ones specifying which of the samples in the matrices in probs are cases (1) and which
are controls (0).
mat.fuzzy
a matrix containing the fuzzy genotype calls. If specified, score and probs are not allowed to be
specified in rowTrendFuzzy.
If NULL, mat.fuzzy is determined by employing g
alternative
a character string specifying the alternative hypothesis. Must be one of "two.sided" (default),
"greater", or "less". Abbreviations (e.g. the initial letter) for these choices are also allowed.
check
logical specifying whether the specified objects should be extensively checked. If FALSE, only some basic
checks are done. It is highly recommended to use check = TRUE, although the checking takes much more computing time